@@ -7,14 +7,23 @@ class WeakFunctionReferences:
         self.references = {}
 
     def add(self, function: typing.Callable):
-        callback_id = hash(function) & 0xffffffffffffff
+        try:
+            _id = function.__self__
+        except:
+            _id = function
+        callback_id = hash("%s%s" % (id(_id), function.__name__)) & 0xffffffffffff
         if callback_id in self.references:
             return callback_id
         self.references[callback_id] = weakref.WeakMethod(function, self._create_delete_callback(callback_id))
         return callback_id
 
     def remove(self, function: typing.Callable):
-        del self.references[hash(function) & 0xffffffffffffff]
+        try:
+            obj = function.__self__
+        except:
+            _id = function
+        callback_id = hash("%s%s" % (id(_id), function.__name__)) & 0xffffffffffff
+        del self.references[callback_id]
 
     def get(self, callback_id: int) -> typing.Callable:
         return self.references[callback_id]()
